"""Long or boring tests for vobjects."""

import vobject, behavior, registry

#------------------- Testing and running functions -----------------------------
def _test():
    import doctest, vobject, tests, icalendar, __init__
    doctest.testmod(vobject, verbose=0)
    doctest.testmod(tests, verbose=0)
    doctest.testmod(icalendar, verbose=0)
    #doctest.testmod(__init__, verbose=0) #doesn't like print x.serialize()
    
if __name__ == '__main__':
    _test()
    
#------------------------------ Tests ------------------------------------------
# See http://cvs.sourceforge.net/viewcvs.py/freeassociation/libical/test-data/
# for good sampledata.


testSilly="""
sillyname:name
profile:sillyprofile
stuff:folded
 line
""" + "morestuff;asinine:this line is not folded, \
but in practice probably ought to be, as it is exceptionally long, \
and moreover demonstratively stupid"

icaltest="""BEGIN:VCALENDAR
CALSCALE:GREGORIAN
X-WR-TIMEZONE;VALUE=TEXT:US/Pacific
METHOD:PUBLISH
PRODID:-//Apple Computer\, Inc//iCal 1.0//EN
X-WR-CALNAME;VALUE=TEXT:Example
VERSION:2.0
BEGIN:VEVENT
SEQUENCE:5
DTSTART;TZID=US/Pacific:20021028T140000
DTSTAMP:20021028T011706Z
SUMMARY:Coffee with Jason
UID:EC9439B1-FF65-11D6-9973-003065F99D04
DTEND;TZID=US/Pacific:20021028T150000
BEGIN:VALARM
TRIGGER;VALUE=DURATION:-P1D
ACTION:DISPLAY
DESCRIPTION:Event reminder
END:VALARM
END:VEVENT
END:VCALENDAR"""


__test__ = { "Test readComponents" :
    """
    >>> import StringIO
    >>> from vobject import readComponents
    >>> f2 = StringIO.StringIO(testSilly) 
    >>> silly = readComponents(f2).next()
    >>> silly
    <sillyprofile| [<MORESTUFF{}this line is not folded, but in practice probably ought to be, as it is exceptionally long, and moreover demonstratively stupid>, <SILLYNAME{}name>, <STUFF{}foldedline>]>
    >>> silly.stuff[0]
    <STUFF{}foldedline>
    >>> original = silly.serialize()
    >>> f3 = StringIO.StringIO(original)
    >>> silly2 = readComponents(f3).next()
    >>> silly2.serialize()==original
    True
    >>> s3 = StringIO.StringIO('cn:Babs Jensen\\r\\ncn:Barbara J Jensen\\r\\nsn:Jensen\\r\\nemail:babs@umich.edu\\r\\nphone:+1 313 747-4454\\r\\nx-id:1234567890\\r\\n')
    >>> ex1 = readComponents(s3).next()
    >>> ex1
    <*unnamed*| [<CN{}Babs Jensen>, <CN{}Barbara J Jensen>, <EMAIL{}babs@umich.edu>, <PHONE{}+1 313 747-4454>, <SN{}Jensen>, <X-ID{}1234567890>]>
    >>> ex1.serialize()
    u'CN:Babs Jensen\\r\\nCN:Barbara J Jensen\\r\\nEMAIL:babs@umich.edu\\r\\nPHONE:+1 313 747-4454\\r\\nSN:Jensen\\r\\nX-ID:1234567890\\r\\n'
    """,
    
    "Validate sampledata.txt" :
    """
    >>> import vobject
    >>> f=open("sampledata.txt")
    >>> c=list(vobject.readComponents(f, validate=True))
    >>> c[1].vevent[0].dtend[0].value
    datetime.datetime(1998, 3, 12, 9, 30, tzinfo=<tzicalvtz 'US-Eastern'>)
    >>> c[1].vevent[0].dtend[0].value.astimezone(registry.getTzid("UTC"))
    datetime.datetime(1998, 3, 12, 13, 30, tzinfo=tzutc())
    >>> f.close()
    >>> f=open("../icalexport.ics")
    >>> c=list(vobject.readComponents(f, validate=True))
    """,
    
    "Import icaltest" :
    """
    >>> import vobject, StringIO
    >>> f=StringIO.StringIO(icaltest)
    >>> registry.registerTzid("US/Pacific", registry.getTzid("UTC"))
    >>> c = vobject.readComponents(f, validate=True).next()
    >>> c.vevent[0].valarm[0].trigger[0].params['VALUE']
    [u'DURATION']
    >>> c.vevent[0].rruleset[0]
    datetime.datetime(2002, 10, 28, 14, 0, tzinfo=tzutc())
    >>> c.vevent[0].dtend[0].value
    datetime.datetime(2002, 10, 28, 15, 0, tzinfo=tzutc())
    >>> c.vevent[0].dtstamp[0].value
    datetime.datetime(2002, 10, 28, 1, 17, 6, tzinfo=tzutc())
    """
    }